@@ -155,6 +155,9 @@ type CheClusterDevEnvironments struct {
 	// If not specified, the pod scheduler is set to the default scheduler on the cluster.
 	// +optional
 	PodSchedulerName string `json:"podSchedulerName,omitempty"`
+	// RuntimeClassName specifies the spec.runtimeClassName for workspace pods.
+	// +optional
+	RuntimeClassName *string `json:"runtimeClassName,omitempty"`
 	// StartTimeoutSeconds determines the maximum duration (in seconds) that a workspace can take to start
 	// before it is automatically failed.
 	// If not specified, the default value of 300 seconds (5 minutes) is used.
@@ -182,6 +185,12 @@ type CheClusterDevEnvironments struct {
 	// +kubebuilder:validation:Minimum:=-1
 	// +optional
 	MaxNumberOfRunningWorkspacesPerUser *int64 `json:"maxNumberOfRunningWorkspacesPerUser,omitempty"`
+	// The maximum number of concurrently running workspaces across the entire Kubernetes cluster.
+	// This applies to all users in the system. If the value is set to -1, it means there is
+	// no limit on the number of running workspaces.
+	// +kubebuilder:validation:Minimum:=-1
+	// +optional
+	MaxNumberOfRunningWorkspacesPerCluster *int64 `json:"maxNumberOfRunningWorkspacesPerCluster,omitempty"`
 	// User configuration.
 	// +optional
 	User *UserConfiguration `json:"user,omitempty"`
@@ -197,8 +206,12 @@ type CheClusterDevEnvironments struct {
 	// if a transient cluster issue is triggering false-positives (for example, if
 	// the cluster occasionally encounters FailedScheduling events). Events listed
 	// here will not trigger workspace failures.
+	// +kubebuilder:default:={"FailedScheduling"}
 	// +optional
-	IgnoredUnrecoverableEvents []string `json:"ignoredUnrecoverableEvents,omitempty"`
+	IgnoredUnrecoverableEvents []string `json:"ignoredUnrecoverableEvents"`
+	// AllowedSources defines the allowed sources on which workspaces can be started.
+	// +optional
+	AllowedSources *AllowedSources `json:"allowedSources,omitempty"`
 }
 
 // Che components configuration.
@@ -661,6 +674,12 @@ type Deployment struct {
 	// Security options the pod should run with.
 	// +optional
 	SecurityContext *PodSecurityContext `json:"securityContext,omitempty"`
+	// The node selector limits the nodes that can run the pod.
+	// +optional
+	NodeSelector map[string]string `json:"nodeSelector,omitempty"`
+	// The pod tolerations of the component pod limit where the pod can run.
+	// +optional
+	Tolerations []corev1.Toleration `json:"tolerations,omitempty"`
 }
 
 // Container custom settings.
@@ -819,6 +838,15 @@ type KubeRbacProxy struct {
 	LogLevel *int32 `json:"logLevel,omitempty"`
 }
 
+type AllowedSources struct {
+	// The list of approved URLs for starting Cloud Development Environments (CDEs). CDEs can only be
+	// initiated from these URLs. Wildcards `*` are supported in URLs, allowing flexible matching for
+	// specific URL patterns. For instance, `https://example.com/*` would allow CDEs to be initiated
+	// from any path within 'example.com'.
+	// +optional
+	Urls []string `json:"urls,omitempty"`
+}
+
 // GatewayPhase describes the different phases of the Che gateway lifecycle.
 type GatewayPhase string
 
@@ -1006,11 +1034,14 @@ func (c *CheCluster) IsCheFlavor() bool {
 // IsEmbeddedOpenVSXRegistryConfigured returns true if the Open VSX Registry is configured to be embedded
 // only if only the `Spec.Components.PluginRegistry.OpenVSXURL` is empty.
 func (c *CheCluster) IsEmbeddedOpenVSXRegistryConfigured() bool {
-	openVSXURL := defaults.GetPluginRegistryOpenVSXURL()
 	if c.Spec.Components.PluginRegistry.OpenVSXURL != nil {
-		openVSXURL = *c.Spec.Components.PluginRegistry.OpenVSXURL
+		return *c.Spec.Components.PluginRegistry.OpenVSXURL == ""
 	}
-	return openVSXURL == ""
+	return defaults.GetPluginRegistryOpenVSXURL() == ""
+}
+
+func (c *CheCluster) IsInternalPluginRegistryDisabled() bool {
+	return c.Spec.Components.PluginRegistry.DisableInternalRegistry || !c.IsEmbeddedOpenVSXRegistryConfigured()
 }
 
 // IsCheBeingInstalled returns true if the Che version is not set in the status.
