@@ -93,6 +93,8 @@ func updateWorkspaceConfig(ctx *chetypes.DeployContext, operatorConfig *controll
 
 	updateWorkspacePodSchedulerNameConfig(devEnvironments, operatorConfig.Workspace)
 
+	updateWorkspaceRuntimeClassNameConfig(devEnvironments, operatorConfig.Workspace)
+
 	updateProjectCloneConfig(devEnvironments, operatorConfig.Workspace)
 
 	if err := updateSecurityContext(operatorConfig, cheCluster); err != nil {
@@ -222,6 +224,10 @@ func updateWorkspacePodSchedulerNameConfig(devEnvironments *chev2.CheClusterDevE
 	workspaceConfig.SchedulerName = devEnvironments.PodSchedulerName
 }
 
+func updateWorkspaceRuntimeClassNameConfig(devEnvironments *chev2.CheClusterDevEnvironments, workspaceConfig *controllerv1alpha1.WorkspaceConfig) {
+	workspaceConfig.RuntimeClassName = devEnvironments.RuntimeClassName
+}
+
 func updateProjectCloneConfig(devEnvironments *chev2.CheClusterDevEnvironments, workspaceConfig *controllerv1alpha1.WorkspaceConfig) {
 	if devEnvironments.ProjectCloneContainer == nil {
 		workspaceConfig.ProjectCloneConfig = nil
